==> AsposeCellsCloud-CellsApi-25.12.tar.gz: AsposeCellsCloud-CellsApi-25.12/docs/model/ArcShape.md <==
# AsposeCellsCloud::Object::ArcShape 

## Load the model package
```perl
use AsposeCellsCloud::Object::ArcShape;
```

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**BeginArrowheadLength** | **string** | Gets and sets the begin arrow head length of the line. |
**BeginArrowheadStyle** | **string** | Gets and sets the begin arrow head style of the line. |
**BeginArrowheadWidth** | **string** | Gets and sets the begin arrow head width of the line. |
**EndArrowheadLength** | **string** | Gets and sets the end arrow head length of the line. |
**EndArrowheadStyle** | **string** | Gets and sets the end arrow head style of the line. |
**EndArrowheadWidth** | **string** | Gets and sets the end arrow head width of the line. |
**Name** | **string** |  |
**MsoDrawingType** | **string** |  |
**AutoShapeType** | **string** |  |
**Placement** | **string** |  |
**UpperLeftRow** | **int** |  |
**Top** | **int** |  |
**UpperLeftColumn** | **int** |  |
**Left** | **int** |  |
**LowerRightRow** | **int** |  |
**Bottom** | **int** |  |
**LowerRightColumn** | **int** |  |
**Right** | **int** |  |
**Width** | **int** |  |
**Height** | **int** |  |
**X** | **int** |  |
**Y** | **int** |  |
**RotationAngle** | **double** |  |
**HtmlText** | **string** |  |
**Text** | **string** |  |
**AlternativeText** | **string** |  |
**TextHorizontalAlignment** | **string** |  |
**TextHorizontalOverflow** | **string** |  |
**TextOrientationType** | **string** |  |
**TextVerticalAlignment** | **string** |  |
**TextVerticalOverflow** | **string** |  |
**IsGroup** | **boolean** |  |
**IsHidden** | **boolean** |  |
**IsLockAspectRatio** | **boolean** |  |
**IsLocked** | **boolean** |  |
**IsPrintable** | **boolean** |  |
**IsTextWrapped** | **boolean** |  |
**IsWordArt** | **boolean** |  |
**LinkedCell** | **string** |  |
**ZOrderPosition** | **int** |  |
**Font** | **Font** |  |
**Hyperlink** | **string** |  |
**link** | **Link** |  |  

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

==> AsposeCellsCloud-CellsApi-26.2.tar.gz: AsposeCellsCloud-CellsApi-26.2/docs/model/ArcShape.md <==
# AsposeCellsCloud::Object::ArcShape 

## Load the model package
```perl
use AsposeCellsCloud::Object::ArcShape;
```

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**BeginArrowheadLength** | **string** | Gets and sets the begin arrow head length of the line. |
**BeginArrowheadStyle** | **string** | Gets and sets the begin arrow head style of the line. |
**BeginArrowheadWidth** | **string** | Gets and sets the begin arrow head width of the line. |
**EndArrowheadLength** | **string** | Gets and sets the end arrow head length of the line. |
**EndArrowheadStyle** | **string** | Gets and sets the end arrow head style of the line. |
**EndArrowheadWidth** | **string** | Gets and sets the end arrow head width of the line. |
**Name** | **string** |  |
**MsoDrawingType** | **string** |  |
**AutoShapeType** | **string** |  |
**Placement** | **string** |  |
**UpperLeftRow** | **int** |  |
**Top** | **int** |  |
**UpperLeftColumn** | **int** |  |
**Left** | **int** |  |
**LowerRightRow** | **int** |  |
**Bottom** | **int** |  |
**LowerRightColumn** | **int** |  |
**Right** | **int** |  |
**Width** | **int** |  |
**Height** | **int** |  |
**X** | **int** |  |
**Y** | **int** |  |
**RotationAngle** | **double** |  |
**HtmlText** | **string** |  |
**Text** | **string** |  |
**AlternativeText** | **string** |  |
**TextHorizontalAlignment** | **string** |  |
**TextHorizontalOverflow** | **string** |  |
**TextOrientationType** | **string** |  |
**TextVerticalAlignment** | **string** |  |
**TextVerticalOverflow** | **string** |  |
**IsGroup** | **boolean** |  |
**IsHidden** | **boolean** |  |
**IsLockAspectRatio** | **boolean** |  |
**IsLocked** | **boolean** |  |
**IsPrintable** | **boolean** |  |
**IsTextWrapped** | **boolean** |  |
**IsWordArt** | **boolean** |  |
**LinkedCell** | **string** |  |
**ZOrderPosition** | **int** |  |
**Font** | **Font** |  |
**Hyperlink** | **string** |  |
**link** | **Link** |  |  


[[Back to Model list]](../DeveloperGuide.md#model-reference)  
[[Back to README]](../../README.md)
